@@ -3,7 +3,7 @@ package RPi::WiringPi::Constant;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '1.00';
 
 require Exporter;
 use base qw( Exporter );
@@ -35,6 +35,29 @@ use constant {
     $EXPORT_TAGS{pinmode} = \@const;
 }
 
+use constant {
+    ALT0 => 4,
+    ALT1 => 5,
+    ALT2 => 6,
+    ALT3 => 7,
+    ALT4 => 3,
+    ALT5 => 2,
+};
+
+{ # alt modes
+    my @const = qw(
+        ALT0
+        ALT1
+        ALT2
+        ALT3
+        ALT4
+        ALT5
+    );
+
+    push @EXPORT_OK, @const;
+    $EXPORT_TAGS{altmode} = \@const;
+}
+
 use constant {
     PUD_OFF => 0,
     PUD_DOWN => 1,
@@ -165,6 +188,17 @@ Pin modes.
     SOFT_TONE_OUTPUT => 5,  # reserved
     PWM_TONE_OUTPUT  => 6,  # reserved
 
+=head2 :altmode
+
+Pin ALT modes.
+
+    ALT0 => 4,
+    ALT1 => 5,
+    ALT2 => 6,
+    ALT3 => 7,
+    ALT4 => 3,
+    ALT5 => 2,
+
 =head2 :pull
 
 Internal pin pull up/down resistor state.
